#ifndef __CLUTTER_DEPRECATED_H__
#define __CLUTTER_DEPRECATED_H__

#define __CLUTTER_DEPRECATED_H_INSIDE__

#include "deprecated/clutter-actor.h"
#include "deprecated/clutter-backend.h"
#include "deprecated/clutter-behaviour.h"
#include "deprecated/clutter-behaviour-depth.h"
#include "deprecated/clutter-behaviour-ellipse.h"
#include "deprecated/clutter-behaviour-opacity.h"
#include "deprecated/clutter-behaviour-path.h"
#include "deprecated/clutter-behaviour-rotate.h"
#include "deprecated/clutter-behaviour-scale.h"
#include "deprecated/clutter-box.h"
#include "deprecated/clutter-container.h"
#include "deprecated/clutter-fixed.h"
#include "deprecated/clutter-frame-source.h"
#include "deprecated/clutter-group.h"
#include "deprecated/clutter-keysyms.h"
#include "deprecated/clutter-main.h"
#include "deprecated/clutter-rectangle.h"
#include "deprecated/clutter-score.h"
#include "deprecated/clutter-shader.h"
#include "deprecated/clutter-stage.h"
#include "deprecated/clutter-timeout-pool.h"

#undef __CLUTTER_DEPRECATED_H_INSIDE__

#endif /* __CLUTTER_DEPRECATED_H__ */
